@@ -26,7 +26,9 @@ Configuration
 from ...internal.utils.importlib import require_modules
 
 
-with require_modules(["algoliasearch", "algoliasearch.version"]) as missing_modules:
+required_modules = ["algoliasearch", "algoliasearch.version"]
+
+with require_modules(required_modules) as missing_modules:
     if not missing_modules:
         from .patch import patch
         from .patch import unpatch
