@@ -50,6 +50,7 @@ class TelemetryWriter(PeriodicService):
         self._events_queue = []  # type: List[Dict]
         self._integrations_queue = []  # type: List[Dict]
         self._lock = forksafe.Lock()  # type: forksafe.ResetObject
+        self._forked = False  # type: bool
 
         # _sequence is a counter representing the number of requests sent by the writer
         self._sequence = 1  # type: int
@@ -77,7 +78,7 @@ class TelemetryWriter(PeriodicService):
                 conn.close()
 
     def _flush_integrations_queue(self):
-        # type () -> List[Dict]
+        # type: () -> List[Dict]
         """Returns a list of all integrations queued by add_integration"""
         with self._lock:
             integrations = self._integrations_queue
@@ -85,13 +86,19 @@ class TelemetryWriter(PeriodicService):
         return integrations
 
     def _flush_events_queue(self):
-        # type () -> List[Dict]
+        # type: () -> List[Dict]
         """Returns a list of all integrations queued by classmethods"""
         with self._lock:
             requests = self._events_queue
             self._events_queue = []
         return requests
 
+    def _reset_queues(self):
+        # type: () -> None
+        with self._lock:
+            self._integrations_queue = []
+            self._events_queue = []
+
     def periodic(self):
         integrations = self._flush_integrations_queue()
         if integrations:
@@ -117,13 +124,18 @@ class TelemetryWriter(PeriodicService):
                     exc_info=True,
                 )
 
+    def _start_service(self, *args, **kwargs):
+        # type: (...) -> None
+        self.app_started_event()
+        return super(TelemetryWriter, self)._start_service(*args, **kwargs)
+
     def on_shutdown(self):
         self._app_closing_event()
         self.periodic()
 
     def _stop_service(self, *args, **kwargs):
         # type: (...) -> None
-        super(TelemetryWriter, self)._stop_service()
+        super(TelemetryWriter, self)._stop_service(*args, **kwargs)
         self.join()
 
     def add_event(self, payload, payload_type):
@@ -168,12 +180,16 @@ class TelemetryWriter(PeriodicService):
     def app_started_event(self):
         # type: () -> None
         """Sent when TelemetryWriter is enabled or forks"""
+        if self._forked:
+            # app-started events should only be sent by the main process
+            return
         # pkg_resources import is inlined for performance reasons
         # This import is an expensive operation
         import pkg_resources
 
         payload = {
             "dependencies": [{"name": pkg.project_name, "version": pkg.version} for pkg in pkg_resources.working_set],
+            "integrations": self._flush_integrations_queue(),
             "configurations": [],
         }
         self.add_event(payload, "app-started")
@@ -181,6 +197,9 @@ class TelemetryWriter(PeriodicService):
     def _app_closing_event(self):
         # type: () -> None
         """Adds a Telemetry request which notifies the agent that an application instance has terminated"""
+        if self._forked:
+            # app-closing event should only be sent by the main process
+            return
         payload = {}  # type: Dict
         self.add_event(payload, "app-closing")
 
@@ -215,11 +234,13 @@ class TelemetryWriter(PeriodicService):
             "request_type": payload_type,
         }
 
-    def _restart(self):
+    def _fork_writer(self):
         # type: () -> None
-        if self.status == ServiceStatus.RUNNING:
-            self.disable()
-        self.enable()
+        self._forked = True
+        # Avoid sending duplicate events.
+        # Queued events should be sent in the main process.
+        self._reset_queues()
+        self.start()
 
     def disable(self):
         # type: () -> None
@@ -228,13 +249,13 @@ class TelemetryWriter(PeriodicService):
         Once disabled, telemetry collection can be re-enabled by calling ``enable`` again.
         """
         with self._lock:
-            self._integrations_queue = []
             self._enabled = False
-            if self.status == ServiceStatus.STOPPED:
-                return
+        self._reset_queues()
+        if self.status == ServiceStatus.STOPPED:
+            return
 
-            forksafe.unregister(self._restart)
-            atexit.unregister(self.stop)
+        forksafe.unregister(self._fork_writer)
+        atexit.unregister(self.stop)
 
         self.stop()
 
@@ -244,15 +265,11 @@ class TelemetryWriter(PeriodicService):
         Enable the instrumentation telemetry collection service. If the service has already been
         activated before, this method does nothing. Use ``disable`` to turn off the telemetry collection service.
         """
-        with self._lock:
-            if self.status == ServiceStatus.RUNNING:
-                return
+        if self.status == ServiceStatus.RUNNING:
+            return
 
-            self.start()
-            self._enabled = True
+        self.start()
+        self._enabled = True
 
-            forksafe.register(self._restart)
-            atexit.register(self.stop)
-
-        # add_event _locks around adding to the events queue
-        self.app_started_event()
+        forksafe.register(self._fork_writer)
+        atexit.register(self.stop)
